==> dwarfg_install_1.4.0.tgz: dwarfg_install/appdir/web/gui/src/Entity/MonitoringGroup/MonitoringGroup.php <==
<?php

declare(strict_types=1);

namespace App\Entity\MonitoringGroup;

use App\Entity\Alert\Alert;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Table(name: 'monitoring_groups')]
#[ORM\Entity]
class MonitoringGroup
{
    /**
     * @var int|null
     */
    #[ORM\Column(type: Types::INTEGER)]
    #[ORM\Id]
    #[ORM\GeneratedValue(strategy: 'AUTO')]
    private ?int $id = null;

    /**
     * @var string
     */
    #[ORM\Column(type: Types::STRING, length: 64, nullable: false)]
    public string $name;

    /**
     * @var Collection
     */
    #[ORM\OneToMany(targetEntity: MonitoringGroupMapping::class, mappedBy: 'monitoringGroup', cascade: ['persist', 'remove'])]
    #[ORM\JoinColumn(name: 'id')]
    public Collection $monitoringGroupMappings;

    /**
     * @var Collection
     */
    #[ORM\OneToMany(targetEntity: Alert::class, mappedBy: 'targetMonitoringGroup', cascade: ['persist'])]
    #[ORM\JoinColumn(name: 'id')]
    public Collection $alerts;

    /**
     * MonitoringGroup constructor.
     */
    public function __construct(){

        $this->monitoringGroupMappings = new ArrayCollection();
        $this->alerts = new ArrayCollection();

    }

    /**
     * @return int|null
     */
    public function getId(): ?int {

        return $this->id;

    }

    /**
     * @return string
     */
    public function getName(): ?string {

        return $this->name;

    }

	/**
	 * @return ArrayCollection
	 */
    public function getMonitoringGroupMappings(): ArrayCollection {

        return $this->monitoringGroupMappings;

    }

    /**
     * @return Collection<int, Alert>
     */
    public function getAlerts(): ArrayCollection {

        return $this->alerts;

    }

}

==> dwarfg_install_1.9.0.tgz: dwarfg_install/appdir/web/gui/src/Entity/MonitoringGroup/MonitoringGroup.php <==
<?php

declare(strict_types=1);

namespace App\Entity\MonitoringGroup;

use App\Entity\Alert\Alert;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Table(name: 'monitoring_groups')]
#[ORM\Entity]
class MonitoringGroup
{
    /**
     * @var int|null
     */
    #[ORM\Column(type: Types::INTEGER)]
    #[ORM\Id]
    #[ORM\GeneratedValue(strategy: 'AUTO')]
    private ?int $id = null;

    /**
     * @var string
     */
    #[ORM\Column(type: Types::STRING, length: 64, nullable: false, options: ['datatable_editable' => true])]
    public string $name;

    /**
     * @var Collection
     */
    #[ORM\OneToMany(targetEntity: MonitoringGroupMapping::class, mappedBy: 'monitoringGroup', cascade: ['persist', 'remove'])]
    #[ORM\JoinColumn(name: 'id')]
    public Collection $monitoringGroupMappings;

    /**
     * @var Collection
     */
    #[ORM\OneToMany(targetEntity: Alert::class, mappedBy: 'targetMonitoringGroup', cascade: ['persist'])]
    #[ORM\JoinColumn(name: 'id')]
    public Collection $alerts;

    /**
     * MonitoringGroup constructor.
     */
    public function __construct(){

        $this->monitoringGroupMappings = new ArrayCollection();
        $this->alerts = new ArrayCollection();

    }

    /**
     * @return int|null
     */
    public function getId(): ?int {

        return $this->id;

    }

    /**
     * @return string
     */
    public function getName(): ?string {

        return $this->name;

    }

	/**
	 * @return ArrayCollection
	 */
    public function getMonitoringGroupMappings(): ArrayCollection {

        return $this->monitoringGroupMappings;

    }

    /**
     * @return Collection<int, Alert>
     */
    public function getAlerts(): ArrayCollection {

        return $this->alerts;

    }

}
